@@ -24,7 +24,9 @@ def get_version_map():
     }
 
 
-def assert_has_keys(dict, required=[], optional=[]):
+def assert_has_keys(dict, required=None, optional=None):
+    required = required or []
+    optional = optional or []
     keys = dict.keys()
     for k in required:
         try:
@@ -163,7 +165,7 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "status": "ACTIVE",
                 "ip": ["10.0.0.13"],
                 "volume": {"size": 2},
-                "flavor": {"id": "2"},
+                "flavor": {"id": "02"},
                 "datastore": {"version": "5.6", "type": "mysql"}},
             {
                 "id": "5678",
@@ -213,7 +215,12 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "str_id": "7d0d16e5-875f-4198-b6da-90ab2d3e899e",
                 "ram": 8192,
                 "id": None,
-                "name": "m1.uuid"}]})
+                "name": "m1.uuid"},
+            {
+                "str_id": "02",
+                "ram": 1024,
+                "id": None,
+                "name": "m1.leading-zero"}]})
 
     def get_datastores_mysql_versions_some_version_id_flavors(self, **kw):
         return self.get_flavors()
@@ -230,14 +237,30 @@ class FakeHTTPClient(base_client.HTTPClient):
         r = {'flavor': self.get_flavors()[2]['flavors'][0]}
         return (200, {}, r)
 
+    def get_flavors_eph_rd_smaller(self, **kw):
+        r = {'flavor': self.get_flavors()[2]['flavors'][1]}
+        return (200, {}, r)
+
     def get_flavors_m1_small(self, **kw):
         r = {'flavor': self.get_flavors()[2]['flavors'][2]}
         return (200, {}, r)
 
+    def get_flavors_m1_medium(self, **kw):
+        r = {'flavor': self.get_flavors()[2]['flavors'][3]}
+        return (200, {}, r)
+
     def get_flavors_m1_uuid(self, **kw):
         r = {'flavor': self.get_flavors()[2]['flavors'][4]}
         return (200, {}, r)
 
+    def get_flavors_02(self, **kw):
+        r = {'flavor': self.get_flavors()[2]['flavors'][5]}
+        return (200, {}, r)
+
+    def get_flavors_m1_leading_zero(self, **kw):
+        r = {'flavor': self.get_flavors()[2]['flavors'][5]}
+        return (200, {}, r)
+
     def get_clusters(self, **kw):
         return (200, {}, {"clusters": [
             {
@@ -246,7 +269,7 @@ class FakeHTTPClient(base_client.HTTPClient):
                         "type": "member",
                         "id": "member-1",
                         "ip": ["10.0.0.3"],
-                        "flavor": {"id": "2"},
+                        "flavor": {"id": "02"},
                         "name": "test-clstr-member-1"
                     },
                     {
@@ -415,7 +438,10 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "datastore_version": 'all',
                 "tenant": 'all',
                 "auto_apply": 0,
-                "visible": 1},
+                "visible": 1,
+                "priority_apply": 0,
+                "apply_order": 5,
+                "is_admin": 0},
             {
                 "id": "8765",
                 "name": "mod2",
@@ -424,7 +450,10 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "datastore_version": 'all',
                 "tenant": 'all',
                 "auto_apply": 0,
-                "visible": 1}]})
+                "visible": 0,
+                "priority_apply": 0,
+                "apply_order": 5,
+                "is_admin": 1}]})
 
     def get_modules_4321(self, **kw):
         r = {'module': self.get_modules()[2]['modules'][0]}
