@@ -175,10 +175,18 @@ class ShellTest(utils.TestCase):
         self.run_command('show 1234')
         self.assert_called('GET', '/instances/1234')
 
+    def test_reset_status(self):
+        self.run_command('reset-status 1234')
+        self.assert_called('POST', '/instances/1234/action')
+
     def test_instance_delete(self):
         self.run_command('delete 1234')
         self.assert_called('DELETE', '/instances/1234')
 
+    def test_instance_force_delete(self):
+        self.run_command('force-delete 1234')
+        self.assert_called('DELETE', '/instances/1234')
+
     def test_instance_update(self):
         self.run_command('update 1234')
         self.assert_called('PATCH', '/instances/1234')
@@ -254,10 +262,22 @@ class ShellTest(utils.TestCase):
         self.run_command('cluster-instances cls-1234')
         self.assert_called('GET', '/clusters/cls-1234')
 
+    def test_cluster_reset_status(self):
+        self.run_command('cluster-reset-status cls-1234')
+        self.assert_called('POST', '/clusters/cls-1234')
+
     def test_cluster_delete(self):
         self.run_command('cluster-delete cls-1234')
         self.assert_called('DELETE', '/clusters/cls-1234')
 
+    def test_cluster_force_delete(self):
+        self.run_command('cluster-force-delete cls-1234')
+        self.assert_called('DELETE', '/clusters/cls-1234')
+
+    def test_boot_fail_with_size_0(self):
+        self.assertRaises(exceptions.ValidationError, self.run_command,
+                          'create test-member-1 1 --size 0 --volume_type lvm')
+
     def test_boot(self):
         self.run_command('create test-member-1 1 --size 1 --volume_type lvm')
         self.assert_called_anytime(
@@ -663,7 +683,8 @@ class ShellTest(utils.TestCase):
                                 'all_tenants': 0,
                                 'module_type': 'type', 'visible': 1,
                                 'auto_apply': 0, 'live_update': 0,
-                                'name': 'mod1'}})
+                                'name': 'mod1', 'priority_apply': 0,
+                                'apply_order': 5}})
 
     def test_module_update(self):
         with mock.patch.object(troveclient.v1.modules.Module, '__repr__',
@@ -750,7 +771,8 @@ class ShellTest(utils.TestCase):
             'POST', '/backups',
             {'backup': {
                 'instance': '1234',
-                'name': 'bkp_1'
+                'name': 'bkp_1',
+                'incremental': False
             }})
 
     def test_backup_copy(self):
@@ -759,6 +781,7 @@ class ShellTest(utils.TestCase):
             'POST', '/backups',
             {'backup': {
                 'name': 'new_bkp',
+                'incremental': False,
                 'backup': {'region': None, 'id': 'bk-1234'}
             }})
 
